Crate bitcoincore_rpc_sotatek

Crate bitcoincore_rpc_sotatek 

Rust Client for Bitcoin Core API

This is a client library for the Bitcoin Core JSON-RPC API.

Re-exports

pub extern crate bitcoincore_rpc_json;
pub extern crate jsonrpc;

Re-exports

pub use crate::json::bitcoin;
pub use bitcoincore_rpc_json as json;

Structs

RpcClient
Client implements a JSON-RPC client for the Bitcoin Core daemon or compatible APIs.

Enums

Auth
The different authentication methods for the client.

Traits

RawTx
Used to pass raw txs into the API.